summaryrefslogtreecommitdiffstats
path: root/webkit/tools/test_shell/layout_test_controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/tools/test_shell/layout_test_controller.h')
-rw-r--r--webkit/tools/test_shell/layout_test_controller.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/webkit/tools/test_shell/layout_test_controller.h b/webkit/tools/test_shell/layout_test_controller.h
index e6c4fd7..3a29544 100644
--- a/webkit/tools/test_shell/layout_test_controller.h
+++ b/webkit/tools/test_shell/layout_test_controller.h
@@ -114,6 +114,9 @@ class LayoutTestController : public CppBoundClass {
void setUserStyleSheetEnabled(const CppArgumentList& args, CppVariant* result);
void setUserStyleSheetLocation(const CppArgumentList& args, CppVariant* result);
+ // Passes this preference through to WebPreferences.
+ void setAuthorAndUserStylesEnabled(const CppArgumentList& args, CppVariant* result);
+
// Puts Webkit in "dashboard compatibility mode", which is used in obscure
// Mac-only circumstances. It's not really necessary, and will most likely
// never be used by Chrome, but some layout tests depend on its presence.
@@ -257,8 +260,9 @@ class LayoutTestController : public CppBoundClass {
void forceRedSelectionColors(const CppArgumentList& args,
CppVariant* result);
// Adds a user script to be injected into new documents.
void addUserScript(const CppArgumentList& args, CppVariant* result);
+ void addUserStyleSheet(const CppArgumentList& args, CppVariant* result);
public:
// The following methods are not exposed to JavaScript.
@@ -257,8 +260,9 @@ class LayoutTestController : public CppBoundClass {
void forceRedSelectionColors(const CppArgumentList& args,
CppVariant* result);
- // Adds a user script to be injected into new documents.
+ // Adds a user script or user style sheet to be injected into new documents.
void addUserScript(const CppArgumentList& args, CppVariant* result);